from fastapi import FastAPI, Body, Depends
from .auth import sign_up, sign_in, create_api_key, authenticate

users_app = FastAPI()

@users_app.post('/sign_up')
async def sign_up_endpoint(email: str = Body(...), password: str = Body(...), invite_code: str = Body(...)):
    return await sign_up(email, password, invite_code)

@users_app.post('/sign_in')
async def sign_in_endpoint(email: str = Body(...), password: str = Body(...)):
    return await sign_in(email, password)

@users_app.post('/create_api_key')
async def create_api_key_endpoint(expiration: int = 15, user = Depends(authenticate)):
    return await create_api_key(expiration, user)



from supabase import create_client, Client
from config.config import Settings

settings = Settings()

def get_supabase() -> Client:
    return create_client(settings.SUPABASE_URL, settings.SUPABASE_KEY)



from pydantic_settings import BaseSettings
import os

print(f"Loading settings from .env")
print(f"Working directory: {os.getcwd()}")
with open('.env', 'r') as file:
    env_contents = file.read()
    print(f"ENV file contents: {env_contents}")
print(f"JWT secret: {os.getenv('JWT_SECRET')}")
print(f"Supabase project URL: {os.getenv('SUPABASE_PROJECT_URL')}")

class Settings(BaseSettings):
    JWT_SECRET: str = os.getenv("JWT_SECRET")
    SUPABASE_URL: str = os.getenv("SUPABASE_PROJECT_URL")
    SUPABASE_KEY: str = os.getenv("SUPABASE_API_KEY")
    
    class Config:
        env_file = '.env'
        env_file_encoding = 'utf-8'
